@@ -27,7 +27,6 @@ import functools
 import logging
 import os
 import pickle
-import warnings
 from copy import deepcopy
 from unittest import mock
 
@@ -178,29 +177,6 @@ class LDAPTest(TestCase):
         self.assertEqual(User.objects.count(), user_count + 1)
         cb_mock.assert_called_with(request)
 
-    def test_deprecated_callable_server_uri(self):
-        self._init_settings(
-            SERVER_URI=lambda: self.server.ldap_uri,
-            USER_DN_TEMPLATE="uid=%(user)s,ou=people,o=test",
-        )
-        user_count = User.objects.count()
-
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-            user = authenticate(username="alice", password="password")
-
-        self.assertIs(user.has_usable_password(), False)
-        self.assertEqual(user.username, "alice")
-        self.assertEqual(User.objects.count(), user_count + 1)
-        self.assertEqual(len(w), 1)
-        self.assertEqual(w[0].category, DeprecationWarning)
-        self.assertEqual(
-            str(w[0].message),
-            "Update AUTH_LDAP_SERVER_URI callable tests.tests.<lambda> to "
-            "accept a positional `request` argument. Support for callables "
-            "accepting no arguments will be removed in a future version.",
-        )
-
     def test_simple_bind(self):
         self._init_settings(USER_DN_TEMPLATE="uid=%(user)s,ou=people,o=test")
         user_count = User.objects.count()
@@ -265,7 +241,7 @@ class LDAPTest(TestCase):
 
     @spy_ldap("simple_bind_s")
     def test_simple_bind_escaped(self, mock):
-        """ Bind with a username that requires escaping. """
+        """Bind with a username that requires escaping."""
         self._init_settings(USER_DN_TEMPLATE="uid=%(user)s,ou=people,o=test")
 
         user = authenticate(username="alice,1", password="password")
@@ -418,7 +394,7 @@ class LDAPTest(TestCase):
 
     @spy_ldap("search_s")
     def test_search_bind_escaped(self, mock):
-        """ Search for a username that requires escaping. """
+        """Search for a username that requires escaping."""
         self._init_settings(
             USER_SEARCH=LDAPSearch(
                 "ou=people,o=test", ldap.SCOPE_SUBTREE, "(uid=%(user)s)"
@@ -1564,29 +1540,6 @@ class LDAPTest(TestCase):
             cache.get("django_auth_ldap.user_dn.alice"), "uid=alice,ou=people,o=test"
         )
 
-    def test_deprecated_cache_groups(self):
-        self._init_settings(
-            USER_SEARCH=LDAPSearch(
-                "ou=people,o=test", ldap.SCOPE_SUBTREE, "(uid=%(user)s)"
-            ),
-            CACHE_GROUPS=True,
-        )
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-            user = authenticate(username="alice", password="password")
-        self.assertIsNotNone(user)
-        self.assertEqual(len(w), 1)
-        self.assertEqual(w[0].category, DeprecationWarning)
-        self.assertEqual(
-            str(w[0].message),
-            "Found deprecated setting AUTH_LDAP_CACHE_GROUP. Use "
-            "AUTH_LDAP_CACHE_TIMEOUT instead.",
-        )
-        # DN is cached.
-        self.assertEqual(
-            cache.get("django_auth_ldap.user_dn.alice"), "uid=alice,ou=people,o=test"
-        )
-
     #
     # Utilities
     #
